Pet

Struct Pet 

pub struct Pet<T, P>(/* private fields */);
A value that is accepted by a given predicate.

Implementations

Source

impl<T, P: Pred<T>> Pet<T, P>

pub fn new(t: T) -> Option<Self>

Attempts to create a new Pet<T, P> from a value t.

If P accepts t, then the result is a Some(..) containing the value t. Otherwise, None is returned.

pub unsafe fn new_unchecked(t: T) -> Self

Creates a new Pet<T, P> from a value t without checking if P accepts t.

pub fn value(self) -> T

Retrieves the value contained in this Pet<T, P>.