pub struct Pet<T, P>(/* private fields */);Expand description
A value that is accepted by a given predicate.
Implementations
Sourceimpl<T, P: Pred<T>> Pet<T, P>
impl<T, P: Pred<T>> Pet<T, P>
Sourcepub fn new(t: T) -> Option<Self>
pub fn new(t: T) -> Option<Self>
Attempts to create a new Pet<T, P> from a value t.
If P accepts t, then the result is a Some(..) containing the value t.
Otherwise, None is returned.
Sourcepub unsafe fn new_unchecked(t: T) -> Self
pub unsafe fn new_unchecked(t: T) -> Self
Creates a new Pet<T, P> from a value t without checking if P accepts t.